@@ -208,15 +208,16 @@ s3_generate_presigned_url <- function(client_method,
   op <- eval(operation_body[[2]][[3]], envir = getNamespace("paws.common"))
 
   original_params <- formals(operation_fun)
-  original_params <- if(!is.null(original_params)) original_params else list()
-  if(!is.null(original_params)) original_params else list()
+  original_params <- if (!is.null(original_params)) original_params else list()
   param_check <- setdiff(names(params), names(original_params))
-  if (!identical(param_check, character(0)) || is.null(param_check)) {
-    stop(sprintf(
-      "Invalid parameter(s) [`%s`] for client method %s",
-      paste(param_check, collapse = "`, `"), client_method
-    ),
-    call. = FALSE
+
+  if (length(param_check) > 0) {
+    stop(
+      sprintf(
+        "Invalid parameter(s) [`%s`] for client method %s",
+        paste(param_check, collapse = "`, `"), client_method
+      ),
+      call. = FALSE
     )
   }
 
@@ -249,11 +250,23 @@ s3_generate_presigned_url <- function(client_method,
 
   # build request
   request <- do.call(
-    "build", list(request = request), envir = getNamespace("paws.common")
+    "build", list(request = request),
+    envir = getNamespace("paws.common")
   )
+
+  signer <- function(config, default) {
+    switch(config[["signature_version"]],
+      "v1" = "v1_sign_request_handler",
+      "s3" = "s3_sign_request_handler",
+      "s3v4" = "s3v4_sign_request_handler",
+      "v4" = "v4_sign_request_handler",
+      default
+    )
+  }
+
   # sign request
   request <- do.call(
-    "sign_v1_auth_query", list(request = request),
+    signer(config, "v1_sign_request_handler"), list(request = request),
     envir = getNamespace("paws.common")
   )
 
